@@ -94,9 +94,6 @@ static void grl_apple_trailers_source_browse (GrlSource *source,
 static void grl_apple_trailers_source_cancel (GrlSource *source,
                                               guint operation_id);
 
-static GrlCaps *grl_apple_trailers_source_get_caps (GrlSource *source,
-                                                    GrlSupportedOps operation);
-
 /* =================== Apple Trailers Plugin  =============== */
 
 gboolean
@@ -165,6 +162,7 @@ grl_apple_trailers_source_new (gboolean high_definition,
                          "source-id", SOURCE_ID,
                          "source-name", SOURCE_NAME,
                          "source-desc", SOURCE_DESC,
+                         "supported-media", GRL_MEDIA_TYPE_VIDEO,
                          "high-definition", high_definition,
 			 "large-poster", xlarge,
                          NULL);
@@ -224,7 +222,6 @@ grl_apple_trailers_source_class_init (GrlAppleTrailersSourceClass * klass)
   source_class->cancel = grl_apple_trailers_source_cancel;
   source_class->supported_keys = grl_apple_trailers_source_supported_keys;
   source_class->browse = grl_apple_trailers_source_browse;
-  source_class->get_caps = grl_apple_trailers_source_get_caps;
 
   g_object_class_install_property (g_class,
                                    PROP_HD,
@@ -620,15 +617,3 @@ grl_apple_trailers_source_cancel (GrlSource *source, guint operation_id)
     op_data->cancelled = TRUE;
   }
 }
-
-static GrlCaps *
-grl_apple_trailers_source_get_caps (GrlSource *source,
-                                    GrlSupportedOps operation)
-{
-  static GrlCaps *caps = NULL;
-
-  if (caps == NULL)
-    caps = grl_caps_new ();
-
-  return caps;
-}
